pub enum Alignment {
Min,
Max,
Stretch,
Center,
}Expand description
Positioning of grid as a string enum - MIN: Grid starts at the left or top of the frame - MAX: Grid starts at the right or bottom of the frame - STRETCH: Grid is stretched to fit the frame - CENTER: Grid is center aligned
Variants