VariableScope

Enum VariableScope 

pub enum VariableScope {
Show 23 variants AllScopes, TextContent, CornerRadius, WidthHeight, Gap, AllFills, FrameFill, ShapeFill, TextFill, StrokeColor, StrokeFloat, EffectFloat, EffectColor, Opacity, FontFamily, FontStyle, FontWeight, FontSize, LineHeight, LetterSpacing, ParagraphSpacing, ParagraphIndent, FontVariations,
}
VariableScope : Scopes allow a variable to be shown or hidden in the variable picker for various fields. This declutters the Figma UI if you have a large number of variables. Variable scopes are currently supported on FLOAT, STRING, and COLOR variables. ALL_SCOPES is a special scope that means that the variable will be shown in the variable picker for all variable fields. If ALL_SCOPES is set, no additional scopes can be set. ALL_FILLS is a special scope that means that the variable will be shown in the variable picker for all fill fields. If ALL_FILLS is set, no additional fill scopes can be set. Valid scopes for FLOAT variables: - ALL_SCOPES - TEXT_CONTENT - WIDTH_HEIGHT - GAP - STROKE_FLOAT - EFFECT_FLOAT - OPACITY - FONT_WEIGHT - FONT_SIZE - LINE_HEIGHT - LETTER_SPACING - PARAGRAPH_SPACING - PARAGRAPH_INDENT Valid scopes for STRING variables: - ALL_SCOPES - TEXT_CONTENT - FONT_FAMILY - FONT_STYLE Valid scopes for COLOR variables: - ALL_SCOPES - ALL_FILLS - FRAME_FILL - SHAPE_FILL - TEXT_FILL - STROKE_COLOR - EFFECT_COLOR Scopes allow a variable to be shown or hidden in the variable picker for various fields. This declutters the Figma UI if you have a large number of variables. Variable scopes are currently supported on FLOAT, STRING, and COLOR variables. ALL_SCOPES is a special scope that means that the variable will be shown in the variable picker for all variable fields. If ALL_SCOPES is set, no additional scopes can be set. ALL_FILLS is a special scope that means that the variable will be shown in the variable picker for all fill fields. If ALL_FILLS is set, no additional fill scopes can be set. Valid scopes for FLOAT variables: - ALL_SCOPES - TEXT_CONTENT - WIDTH_HEIGHT - GAP - STROKE_FLOAT - EFFECT_FLOAT - OPACITY - FONT_WEIGHT - FONT_SIZE - LINE_HEIGHT - LETTER_SPACING - PARAGRAPH_SPACING - PARAGRAPH_INDENT Valid scopes for STRING variables: - ALL_SCOPES - TEXT_CONTENT - FONT_FAMILY - FONT_STYLE Valid scopes for COLOR variables: - ALL_SCOPES - ALL_FILLS - FRAME_FILL - SHAPE_FILL - TEXT_FILL - STROKE_COLOR - EFFECT_COLOR

Variants



AllScopes



TextContent



CornerRadius



WidthHeight



Gap



AllFills



FrameFill



ShapeFill



TextFill



StrokeColor



StrokeFloat



EffectFloat



EffectColor



Opacity



FontFamily



FontStyle



FontWeight



FontSize



LineHeight



LetterSpacing



ParagraphSpacing



ParagraphIndent



FontVariations