pub struct WidgetNode {Show 14 fields
pub id: String,
pub name: String,
pub visible: Option<bool>,
pub locked: Option<bool>,
pub is_fixed: Option<bool>,
pub scroll_behavior: ScrollBehavior,
pub rotation: Option<f64>,
pub component_property_references: Option<HashMap<String, String>>,
pub plugin_data: Option<Option<Value>>,
pub shared_plugin_data: Option<Option<Value>>,
pub bound_variables: Option<Box<IsLayerTraitBoundVariables>>,
pub explicit_variable_modes: Option<HashMap<String, String>>,
pub export_settings: Option<Vec<ExportSetting>>,
pub children: Vec<SubcanvasNode>,
}Fields
id: StringA string uniquely identifying this node within the document.
name: StringThe name given to the node by the user in the tool.
visible: Option<bool>Whether or not the node is visible on the canvas.
locked: Option<bool>If true, layer is locked and cannot be edited
is_fixed: Option<bool>Whether the layer is fixed while the parent is scrolling
scroll_behavior: ScrollBehaviorHow layer should be treated when the frame is resized
rotation: Option<f64>The rotation of the node, if not 0.
component_property_references: Option<HashMap<String, String>>A mapping of a layer’s property to component property name of component properties attached to this node. The component property name can be used to look up more information on the corresponding component’s or component set’s componentPropertyDefinitions.
plugin_data: Option<Option<Value>>bound_variables: Option<Box<IsLayerTraitBoundVariables>>explicit_variable_modes: Option<HashMap<String, String>>A mapping of variable collection ID to mode ID representing the explicitly set modes for this node.
export_settings: Option<Vec<ExportSetting>>An array of export settings representing images to export from the node.
children: Vec<SubcanvasNode>An array of nodes that are direct children of this node
Implementations
Sourceimpl WidgetNode
impl WidgetNode
pub fn new( id: String, name: String, scroll_behavior: ScrollBehavior, children: Vec<SubcanvasNode>, ) -> WidgetNode